==> mono_1.2.2.1.orig.tar.gz: mono-1.2.2.1/mcs/class/corlib/System.Runtime.InteropServices/RegistrationClassContext.cs <==
//
// System.Runtime.InteropServices.RegistrationClassContext
//
// Author:
//   Kazuki Oikawa  (kazuki@panicode.com)

//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


#if NET_2_0

using System;

namespace System.Runtime.InteropServices
{
	[Flags]
	public enum RegistrationClassContext
	{
		DisableActivateAsActivator = 32768,
		EnableActivateAsActivator = 65536,
		EnableCodeDownload = 8192,
		FromDefaultContext = 131072,
		InprocHandler = 2,
		InprocHandler16 = 32,
		InprocServer = 1,
		InprocServer16 = 8,
		LocalServer = 4,
		NoCodeDownload = 1024,
		NoCustomMarshal = 4096,
		NoFailureLog = 16384,
		RemoteServer = 16,
		Reserved1 = 64,
		Reserved2 = 128,
		Reserved3 = 256,
		Reserved4 = 512,
		Reserved5 = 2048
	}
}
#endif

==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mcs/class/corlib/System.Runtime.InteropServices/RegistrationClassContext.cs <==
//
// System.Runtime.InteropServices.RegistrationClassContext
//
// Author:
//   Kazuki Oikawa  (kazuki@panicode.com)

//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


#if NET_2_0

using System;

namespace System.Runtime.InteropServices
{
	[Flags]
	public enum RegistrationClassContext
	{
		DisableActivateAsActivator = 32768,
		EnableActivateAsActivator = 65536,
		EnableCodeDownload = 8192,
		FromDefaultContext = 131072,
		InProcessHandler = 2,
		InProcessHandler16 = 32,
		InProcessServer = 1,
		InProcessServer16 = 8,
		LocalServer = 4,
		NoCodeDownload = 1024,
		NoCustomMarshal = 4096,
		NoFailureLog = 16384,
		RemoteServer = 16,
		Reserved1 = 64,
		Reserved2 = 128,
		Reserved3 = 256,
		Reserved4 = 512,
		Reserved5 = 2048,
	}
}
#endif
